/*
This code produces the following output:

* Figure 2
* Figure 5

Code should be run sequentially, in order.

*/

**Set directories. Select the directory where the analysis data is located, one where temporary files will be stored as the code runs, and directories for table and figure output.
global YOUR_PATH_HERE " "

*Analysis Data File Directory:
global input_path "${YOUR_PATH_HERE}\3 replication package\data\input\"
*Temporary Folder Directory (to store output and temporary data file)
global temp_path "${YOUR_PATH_HERE}\3 replication package\data\temp"
*Folder to store tables
global tables_path "${YOUR_PATH_HERE}\3 replication package\output\tables"
*Folder to store figures
global figures_path "${YOUR_PATH_HERE}\3 replication package\output\figures"




*Bring in the analysis data
use "${input_path}year6_weeklysurveys_anlaysis_file_anonymized1.dta", clear 



*number of weekly exercises/surveys completed
bys anonymized_student_id: egen num_completed = sum(datetime_finished_exercise!=.)

*keep only student-weeks where week is completed and information exists 
keep if datetime_finished_exercise!=.

*drop control (non-study time focused weekly group) 
drop if treated==0

*Keep only students who completed at least 6 exercises:
keep if num_completed>=6 & num_completed<.
 
egen tag_id = tag(anonymized_student_id)


*******************************************************************
***Number of days from FIRST midterm and each exercise compelted***
*******************************************************************

*get SIF format of DAY midterm 1 was written
gen midterm1_days = date(midterm1_date , "DMY") //format midterm1_date_DMY %td
*get SIF format of DAY each exercise was completed 
tostring datetime_finished_exercise, g(datetime_finished_exercise1) format(%tcnn/dd/ccYY_hh:MM) force
gen exercise_days = date(datetime_finished_exercise1 , "MDYhm")
*gen number of days between midterm and each exercise
gen numdays_btwn_exercise_mid1 =   exercise_days -  midterm1_days


*When are students completing these "weeks" relative to sept 1
gen baseline_date = date("1Sept2019", "DMY")
gen days_since_baseline = exercise_days - baseline_date
tabstat days_since_baseline , by(week) s(mean max min)


*Create week indicators from sept 1 (exercise date relative to sept 1 in weeks)
gen week_since_baseline = days_since_baseline/7
replace week_since_baseline = ceil(week_since_baseline)
tab week_since_baseline

*when do midterms occur? (midterm date relative to sept 1 in weeks)
gen midterm_days_since_base = midterm1_days -  baseline_date
gen midterm_weeks_since_base= midterm_days_since_base /7
replace midterm_weeks_since_base = ceil(midterm_weeks_since_base)
tab midterm_weeks_since_base



*Create bins for weeks before and after first midterm

gen weeks_btwn_mid1_exercise = week_since_baseline - midterm_weeks_since_base
tab weeks_btwn_mid1_exercise


*******************************************************************************************************
*******************************************************************************************************
*******************************************************************************************************
*******************************************************************************************************

/*

Details about these variables:

		- baseline_date: the day school starts, which Sunday Sept 1, 2019
		- A week is 7 days
		- week_since_baseline: number of weeks (7-day intervals) between exercise date and baseline date
		- midterm_weeks_since_base: number of weeks (7-day intervals) between midterm date and baseline date.
		- weeks_btwn_mid1_exercise: number of weeks (7-day intervals) between exercise date and midterm date, i.e., week_since_baseline - midterm_weeks_since_base
		
Other Notes: 
		- The first midterm occured in either the 6th week of school (all instructors except one) or 8th week (that one instructor). 
		- Therefore, conditional on week of school, there is not much variation in week of exercise relative to midterm.
		- Cannot control for week of school fixed effects when exploring week relative to midterm effects

	See the limited variation here:
*/
tab week_since_baseline weeks_btwn_mid1_exercise 

*******************************************************************************************************
*******************************************************************************************************
*******************************************************************************************************
*******************************************************************************************************

scalar start_week  = -5
scalar end_week  = 5

replace weeks_btwn_mid1_exercise=`=scalar(start_week)' if weeks_btwn_mid1_exercise<=`=scalar(start_week)' & weeks_btwn_mid1_exercise<.
replace weeks_btwn_mid1_exercise=`=scalar(end_week)' if weeks_btwn_mid1_exercise>=`=scalar(end_week)' & weeks_btwn_mid1_exercise<.

egen tweek = tag(weeks_btwn_mid1_exercise)



**** Let's make a nice graph to clearly visualize these estimates in each year:
tab weeks_btwn_mid1_exercise
forvalues i =  `=scalar(start_week)'/0{
local j = -1*`i'
gen midterm_minus_`j' = weeks_btwn_mid1_exercise==`i' if weeks_btwn_mid1_exercise<.
}
forvalues i = 1/`=scalar(end_week)'{
gen midterm_plus_`i' = weeks_btwn_mid1_exercise==`i' if weeks_btwn_mid1_exercise<.
}

global week_indicators_minus "midterm_minus_5 midterm_minus_4 midterm_minus_3 midterm_minus_2 midterm_minus_0"
global week_indicators_plus "midterm_plus_1 midterm_plus_2 midterm_plus_3 midterm_plus_4 midterm_plus_5"
global week_indicators "$week_indicators_plus $week_indicators_minus"




gen positive_ability_update  = ability_update>0 if ability_update<.
gen negative_ability_update = 1 - positive_ability_update


forvalues j =1/`=scalar(end_week)'{
gen worse_midterm_plus_`j' = midterm_plus_`j'*negative_ability_update
gen better_midterm_plus_`j' = midterm_plus_`j'*positive_ability_update
}
forvalues j =0/`=scalar(end_week)'{
gen worse_midterm_minus_`j' = midterm_minus_`j'*negative_ability_update 
gen better_midterm_minus_`j' = midterm_minus_`j'*positive_ability_update 
}
*
global worse_week_indicators_better "midterm_minus_5 midterm_minus_4 midterm_minus_3 midterm_minus_2 midterm_minus_0 midterm_plus_1 midterm_plus_2 midterm_plus_3 midterm_plus_4 midterm_plus_5"
global worse_week_indicators_worse  "worse_midterm_minus_5 worse_midterm_minus_4 worse_midterm_minus_3 worse_midterm_minus_2 worse_midterm_minus_0 worse_midterm_plus_1 worse_midterm_plus_2 worse_midterm_plus_3 worse_midterm_plus_4 worse_midterm_plus_5"
global worse_week_indicators "$worse_week_indicators_better $worse_week_indicators_worse"


global betterworse_week_better "better_midterm_minus_5 better_midterm_minus_4 better_midterm_minus_3 better_midterm_minus_2 better_midterm_minus_0 better_midterm_plus_1 better_midterm_plus_2 better_midterm_plus_3 better_midterm_plus_4 better_midterm_plus_5"
global betterworse_week_worse  "worse_midterm_minus_5 worse_midterm_minus_4 worse_midterm_minus_3 worse_midterm_minus_2 worse_midterm_minus_0 worse_midterm_plus_1 worse_midterm_plus_2 worse_midterm_plus_3 worse_midterm_plus_4 worse_midterm_plus_5"
global betterworse_week_indicators  "$betterworse_week_better $betterworse_week_worse"

gen procrast = planned_w - actual_w



*Raw graphs on which event studies are based:

cd "${figures_path}" 

***************************************
**#  Figure 5a: Expected Overall Average Grade
****************************************
binscatter planned_grade_w_ weeks_btwn_mid1_exercise , by(negative_ability_update) line(connect) xline(-1, lcolor(gs5)) ///
legend(label(1 "Positive Ability Update") label(2 "Negative Ability Update") size(vsmall)) ///
ytitle(Planned Grade) xtitle(Week Exercise Completed Relative to Midterm 1 Date, size(medsmall)) xlabel(`=scalar(start_week)'(1)`=scalar(end_week)') msymbols(O t) mcolors(gs10 gs0) lcolors(gs10 gs0)
graph export "Figure_5a.pdf", as(pdf) replace
graph export "Figure_5a.png", as(png) name("Graph") replace



***************************************
**#  Figure 5c: Planned Weekly Study Time Weeks without Midterms
****************************************
binscatter no_midterm_hour_w weeks_btwn_mid1_exercise , by(negative_ability_update) line(connect) xline(-1, lcolor(gs5)) ///
legend(label(1 "Positive Ability Update") label(2 "Negative Ability Update") size(vsmall)) ///
ytitle(Typical Week Without Midterm Study Time) xtitle(Week Exercise Completed Relative to Midterm 1 Date, size(medsmall)) xlabel(`=scalar(start_week)'(1)`=scalar(end_week)') msymbols(O t) mcolors(gs10 gs0) lcolors(gs10 gs0)
graph export "Figure_5c.pdf", as(pdf) replace
graph export "Figure_5c.png", as(png) name("Graph") replace


**********************************************
**# Figures 5b and 5d
***********************************************
gen week_since_worse =.
gen week_since_better =.
gen beta_worse = .
gen ci_l_worse=.
gen ci_u_worse=.
gen beta_better  = .
gen ci_l_better =.
gen ci_u_better =.


set more off
foreach var in planned_grade_w_  no_midterm_hour_w_ {

if "`var'" == "planned_grade_w_"{
local labs1 "Planned Grade"
local labs2 "Figure_5b"
}

else if "`var'" == "no_midterm_hour_w_"{
local labs1 "Weekly Study in Week with No Midterm"
local labs2 "Figure_5d"

}

areg `var' ${betterworse_week_indicators} , a(anonymized_student_id) cluster(anonymized_student_id) 

local i = 1
forvalues x = `=scalar(start_week)'(1)0{
local j = -1*`x'
if `x'==-1{
foreach lab in better worse {
qui replace week_since_`lab'=`x' if _n== `i'
qui replace beta_`lab' = . if _n ==  `i'
qui replace ci_u_`lab' = . if _n== `i'
qui replace ci_l_`lab' = . if _n== `i'
}
local i = `i'+1
}
else{
foreach lab in better worse {
qui replace week_since_`lab'=`x' if _n==`i'
qui lincom `lab'_midterm_minus_`j' 
qui replace beta_`lab' = r(estimate) if _n == `i'
qui replace ci_u_`lab' = r(estimate) + r(se)*invttail(r(df),0.025) if _n==`i'
qui replace ci_l_`lab' = r(estimate) + r(se)*invttail(r(df),0.975) if _n==`i'
}
local i = `i'+1

}
}
local i = -1*(`=scalar(start_week)') + 2
forvalues x = 1/`=scalar(end_week)'{
foreach lab in better worse {
qui replace week_since_`lab'=`x' if _n==`i'
qui lincom `lab'_midterm_plus_`x' 
qui replace beta_`lab' = r(estimate) if _n == `i'
qui replace ci_u_`lab' = r(estimate) + r(se)*invttail(r(df),0.025) if _n==`i'
qui replace ci_l_`lab' = r(estimate) + r(se)*invttail(r(df),0.975) if _n==`i'
}
local i = `i'+1
}
twoway scatter beta_worse week_since_worse , mcolor(gs0) msymbol(t) || ///
rcap ci_l_worse ci_u_worse   week_since_worse , lpattern(dash) lwidth(thin)  color(gs0) || ///
scatter beta_better week_since_worse , mcolor(gs10) msymbol(O)  || ///
rcap ci_l_better ci_u_better   week_since_worse , lpattern(dash) lwidth(thin)  color(gs10) || ///
, scheme(sj) graphregion(icolor(white) color(white))   yline(0, lcolor(gs5)) xlabel(`=scalar(start_week)'(1)`=scalar(end_week)') title(`labs1' Before and After Midterm, size(medium)) ytitle(`labs1', size(small)) xtitle(Week Exercise Completed ///
Relative to Midterm 1 Date, size(medsmall)) legend(label(1 "Negative Ability Update") label(3 "Positive Abiltiy Update") order(3 1) size(vsmall) ) xline(-1, lcolor(gs5))  
graph export "`labs2'.pdf", as(pdf) replace
graph export "`labs2'.png", as(png) name("Graph") replace

}


*end of Figure 5



**********************************************
**# Figure 2: Planned minus Actual Reported Weekly Study Time
***********************************************

sum  procrast
scalar avg_pro = r(mean)


tab weeks_btwn_mid1_exercise
gen mean_proc = .
gen ci_l_proc = . 
gen ci_u_proc = . 

forvalues i=-5/5 {
	reg procrast if weeks_btwn_mid1_exercise==`i'
	replace mean_proc = _b[_cons] if weeks_btwn_mid1_exercise==`i'
	replace ci_u_proc = _b[_cons] + invttail(e(df_r),0.025)*_se[_cons] if weeks_btwn_mid1_exercise==`i'
	replace ci_l_proc  = _b[_cons] - invttail(e(df_r),0.025)*_se[_cons] if weeks_btwn_mid1_exercise==`i'

}

preserve 

sum  procrast
scalar avg_pro = r(mean)
keep mean_proc ci_l_proc ci_u_proc weeks_btwn_mid1_exercise
collapse mean_proc ci_l_proc ci_u_proc, by(weeks_btwn_mid1_exercise)

twoway (connect mean_proc weeks_btwn_mid1_exercise, lcolor(gs0) mcolor(gs0)) || ///
(line ci_l_proc  weeks_btwn_mid1_exercise, lcolor(gs10) lpattern(dash)) || ///
(line ci_u_proc  weeks_btwn_mid1_exercise, lcolor(gs10) lpattern(dash))  ///
, scheme(sj) graphregion(icolor(white) color(white))  yline(`=scalar(avg_pro)', lcolor(gs5)) ///
ytitle(Procrastination: Planned - Actual Study Time) xtitle(Week Exercise Completed Relative to Midterm 1 Date, size(medsmall)) xlabel(`=scalar(start_week)'(1)`=scalar(end_week)') legend(label(1 "Mean Weekly Procrastination") label(2 "95% CI") order(1 2)) ///
ylabel(2(.5)7.5)
graph export "Figure_2.pdf", as(pdf) replace
graph export "Figure_2.png", as(png) name("Graph") replace



restore

*end Figure 2