/*
This code produces the following output:

* Table 4  [Can only replicate columns 1, 3, 5 -- those without control variables. Do so without campus fixed effects.]
* Table 5: Columns 2 & 3
* Table 6 [Can only replicate columns 1, 3, 5 -- those without control variables.]
* Table 8 [Replicate without campus fixed effects.]

* Table B5 [Not possible with data in replication packageon package]
* Table B6: Columns 2 & 3 [Not possible with data in replication packageon package]

* Figure 1: a
* Figure 3: a & b
* Figure 4: a & b 
* Figure 6

* Figure B1: a & b

Code should be run sequentially, in order.
*/


**Set directories. Select the directory where the analysis data is located, one where temporary files will be stored as the code runs, and directories for table and figure output.
global YOUR_PATH_HERE " "

*Analysis Data File Directory:
global input_path "${YOUR_PATH_HERE}\3 replication package\data\input\"
*Temporary Folder Directory (to store output and temporary data file)
global temp_path "${YOUR_PATH_HERE}\3 replication package\data\temp"
*Folder to store tables
global tables_path "${YOUR_PATH_HERE}\3 replication package\output\tables"
*Folder to store figures
global figures_path "${YOUR_PATH_HERE}\3 replication package\output\figures"



*Bring in the analysis data
use "${input_path}year5_April2022FlwUp_anlaysis_file_anonymized1.dta", clear 

/*
***********************************************
* Define some added controls
***********************************************
*/

**Cannot do this with publicly available data
/*
global controls "c.exp_econ_grade##c.exp_econ_grade##c.exp_econ_grade c.studyhours_expected##c.studyhours_expected##c.studyhours_expected c.econ_xstudyhrs_expected##c.econ_xstudyhrs_expected##c.studyhours_expected english male age days_since_sept1 first_year_student econ_xstudyhrs_expected studyhours_expected i.relative_grade international_student first_gen intends_morethan_BA like_study use_calendar_often first_midterm_sets_tone studying_over_friends grades_dont_matter_aftergradu manage_time_well crammer i.campus commute_length expected_work"

global controls_followup "male age  english intends_morethan_BA first_gen expects_A_ormore studyhours_expected expected_work_hours_perweek tend_not_to_cram0 studyhours_hs commute_length  international_student survey_first_year"
*/


/*
***********************************************
*	House Keeping: Clean up Study Gradients
***********************************************
*/
sum expected_study_ability0 expected_study_ability1 expected_study_return0 expected_study_return1, detail 

replace expected_study_ability0=. if expected_study_return0<0
replace expected_study_return0=. if expected_study_return0<0
replace expected_study_ability1=. if expected_study_return1<0
replace expected_study_return1=. if expected_study_return1<0


gen ability_update = expected_study_ability1 - expected_study_ability0
gen slope_update = expected_study_return1 - expected_study_return0


sum ability_update slope_update , detail



/*
***********************************************
* Create infor updating variables
***********************************************
*/

*Get the difference betweeen what they DID study during sem in econ relative to what they expected at baseline:
gen actual_study_diff_econ =  econ_study_hours - econ_xstudyhrs_expected
*Get the difference in the grade they expect to get now in econ and what they expected at baseline
gen diff_exp_grade_econ = expected_econ_grade - exp_econ_grade
*Get the diff in actual econ grade and expected at baseline:
gen actual_minus_exp_econgrade0 = mean_econgrade_fall - exp_econ_grade


*Change in study hours for all courses 
gen changeinhours1 = studyhours_FallSemester - studyhours_expected 



/*
**************************************************
*Preferences for good grades and procrasination
***************************************************
*/
gen pref_forA = studyhours_for_80 - studyhours_for_70 
gen pref_forAplus = studyhours_for_85 - studyhours_for_75
gen procrastination =  studyhours_NextSemester - studyhours_FallSemester
foreach y in distraction_socmedia distraction_video{
sum `y' if treated==0
gen s`y' = (`y' - r(mean))/r(sd)
}
egen sprocrast = rowmean(sdistraction_socmedia sdistraction_video)





**# Appendix B: Common Costs
sum expected_work, detail
gen alotofwork = expected_work > r(p75) if expected_work<.
sum commute_length, detail
gen longcommue = commute_length > r(p75) if commute_length<.
sum workhours_FallSemester, detail 
gen alotofwork2 = workhours_FallSemeste > r(p90) if workhours_FallSemeste<.


reg pref_forAplus alotofwork
reg pref_forAplus longcommue 

reg procrastination alotofwork
reg procrastination longcommue 



/*
********************************************************************************
********************************************************************************
********************************************************************************

		Tables & Figures

********************************************************************************
********************************************************************************
********************************************************************************
*/


**# Appendix B: Linear Approx
sum r2_0 r2_1 r2q_0 r2q_1, detail
corr r2_0 r2q_0
corr r2_1 r2q_1

*end Correlations


cd "${tables_path}" 

****************************************************
****************************************************
****************************************************

**# Table B5: Mean Differences Between 2018-19 Students Taking Study Time Follow-Up Survey

****************************************************
****************************************************
****************************************************

/*
foreach var of varlist mothers_education fathers_education{
	replace `var' = . if `var'==9
}
gen parent_grad = (fathers>=7|mothers>=7) if mothers<. & fathers<.
gen hsmissing= hsgrade==.

*Table for in-followup differences
foreach var of varlist treated intends_morethan_BA  mothers_education fathers_education first_gen parent_grad survey_first_year international_student tend_not_to_cram0  studyhours_expected expected_work_hours_perweek expects_A_ormore days_since_sept1  grit_finish_what_i_begin english male age  hsmissing hsgrade {
	
	
	reg `var' in_2022followup i.campus, r
	if "`var'"=="treated" {
	outreg2 using Table_B5_diff, bracket  aster(se) bdec(2) sdec(3) keep(in_2022followup) excel replace
	}
	else {
	outreg2 using Table_B5_diff, bracket  aster(se) bdec(2) sdec(3) keep(in_2022followup) excel
	}
}
*without campus FEs to get out of follow-up baseline mean
foreach var of varlist treated intends_morethan_BA  mothers_education fathers_education first_gen parent_grad survey_first_year international_student tend_not_to_cram0  studyhours_expected expected_work_hours_perweek expects_A_ormore days_since_sept1  grit_finish_what_i_begin english male age  hsmissing hsgrade {
	
	
	reg `var' in_2022followup, r
	if "`var'"=="treated" {
	outreg2 using Table_B5_baseline , bracket  aster(se) bdec(2) sdec(3) excel  replace
	}
	else {
	outreg2 using Table_B5_baseline , bracket  aster(se) bdec(2) sdec(3)  excel
	}
	
}
tab in_2022followup if treated<.
*/

*end Table B5





****************************************************
****************************************************
****************************************************

**# Table 4: Estimated Effects on Study Times in Follow-Up Sample from 2018-19 Cohort

****************************************************
****************************************************



** Can only replicate columns 1, 3, 5 -- those without control variables.
** The specifications in these columns in the paper include campus fixed effects
** We construct resutls withouth campus fixed effects here, which are only slighlty different.

/*
*Panel A
tabstat reported_more reported_accurate reported_less, by(treated) s(mean sd n)

reg reported_accurate treated i.campus, robust
outreg2 using Table_4a, bracket  aster(se) bdec(2) sdec(3)  replace keep(treated) excel 
reg reported_accurate treated i.campus  ${controls_followup}, robust
outreg2 using Table_4a, bracket  aster(se) bdec(2) sdec(3)   keep(treated) excel
reg reported_more treated i.campus, robust
outreg2 using Table_4a, bracket  aster(se) bdec(2) sdec(3)  keep(treated) excel
reg reported_more treated i.campus ${controls_followup}, robust
outreg2 using Table_4a, bracket  aster(se) bdec(2) sdec(3)   keep(treated) excel
reg reported_less treated i.campus, robust
outreg2 using Table_4a, bracket  aster(se) bdec(2) sdec(3)   keep(treated) excel
reg reported_less treated i.campus ${controls_followup}, robust
outreg2 using Table_4a, bracket  aster(se) bdec(2) sdec(3)   keep(treated) excel


*Panel B
reg studyhours_FallSemester treated i.campus if in_2022followup, robust
outreg2 using Table_4b, bracket  aster(se) bdec(2) sdec(3) replace keep(treated) excel
reg studyhours_FallSemester treated i.campus  ${controls_followup} if in_2022followup  , robust
outreg2 using Table_4b, bracket  aster(se) bdec(2) sdec(3)   keep(treated) excel

reg studyhours_FallSemester treated i.campus if reported_more==1 , robust
outreg2 using Table_4b, bracket  aster(se) bdec(2) sdec(3)   keep(treated) excel
reg studyhours_FallSemester treated i.campus  ${controls_followup} if reported_more==1 , robust
outreg2 using Table_4b, bracket  aster(se) bdec(2) sdec(3)   keep(treated) excel

reg studyhours_FallSemester treated i.campus if reported_accurate==1 , robust
outreg2 using Table_4b, bracket  aster(se) bdec(2) sdec(3)   keep(treated) excel
reg studyhours_FallSemester treated i.campus  ${controls_followup} if reported_accurate==1 , robust
outreg2 using Table_4b, bracket  aster(se) bdec(2) sdec(3)   keep(treated) excel

sum studyhours_FallSemester if in_2022followup==1 & treated==0
sum studyhours_FallSemester if reported_more==1 & treated==0
sum studyhours_FallSemester if reported_accurate==1  & treated==0




*Panel C
reg current_normal treated i.campus if in_2022followup, r
outreg2 using Table_4c, bracket  aster(se) bdec(2) sdec(3)  keep(treated) excel replace
reg current_normal treated i.campus ${controls_followup}, r
outreg2 using Table_4c, bracket  aster(se) bdec(2) sdec(3)   keep(treated) excel


reg current_normal treated i.campus  if reported_more==1, r
outreg2 using Table_4c, bracket  aster(se) bdec(2) sdec(3)   keep(treated) excel
reg current_normal treated i.campus ${controls_followup} if reported_more==1,r
outreg2 using Table_4c, bracket  aster(se) bdec(2) sdec(3)   keep(treated) excel

reg current_normal treated i.campus  if reported_accurate==1, r
outreg2 using Table_4c, bracket  aster(se) bdec(2) sdec(3)   keep(treated) excel
reg current_normal treated i.campus ${controls_followup} if reported_accurate==1, r
outreg2 using Table_4c, bracket  aster(se) bdec(2) sdec(3)   keep(treated) excel


sum current_normal if in_2022followup==1 & treated==0
sum current_normal if reported_more==1 & treated==0
sum current_normal if reported_accurate==1  & treated==0


*Panel D
reg current_exam treated i.campus if in_2022followup, r
outreg2 using Table_4d, bracket  aster(se) bdec(2) sdec(3) keep(treated) excel replace
reg current_exam treated i.campus ${controls_followup}, r
outreg2 using Table_4d, bracket  aster(se) bdec(2) sdec(3)   keep(treated) excel

reg current_exam treated i.campus  if reported_more==1, r
outreg2 using Table_4d, bracket  aster(se) bdec(2) sdec(3)   keep(treated) excel
reg current_exam treated i.campus ${controls_followup} if reported_more==1, r
outreg2 using Table_4d, bracket  aster(se) bdec(2) sdec(3)   keep(treated) excel

reg current_exam treated i.campus  if reported_accurate==1, r
outreg2 using Table_4d, bracket  aster(se) bdec(2) sdec(3)   keep(treated) excel
reg current_exam treated i.campus ${controls_followup} if reported_accurate==1, r
outreg2 using Table_4d, bracket  aster(se) bdec(2) sdec(3)   keep(treated) excel

sum current_exam if in_2022followup==1 & treated==0
sum current_exam if reported_more==1 & treated==0
sum current_exam if reported_accurate==1  & treated==0
*/

*Panel A
tabstat reported_more reported_accurate reported_less, by(treated) s(mean sd n)

reg reported_accurate treated  , robust
outreg2 using Table_4a, bracket  aster(se) bdec(2) sdec(3)  replace keep(treated) excel 

reg reported_more treated  , robust
outreg2 using Table_4a, bracket  aster(se) bdec(2) sdec(3)  keep(treated) excel

reg reported_less treated  , robust
outreg2 using Table_4a, bracket  aster(se) bdec(2) sdec(3)   keep(treated) excel



*Panel B
reg studyhours_FallSemester treated   if in_2022followup, robust
outreg2 using Table_4b, bracket  aster(se) bdec(2) sdec(3) replace keep(treated) excel


reg studyhours_FallSemester treated  if reported_more==1 , robust
outreg2 using Table_4b, bracket  aster(se) bdec(2) sdec(3)   keep(treated) excel


reg studyhours_FallSemester treated   if reported_accurate==1 , robust
outreg2 using Table_4b, bracket  aster(se) bdec(2) sdec(3)   keep(treated) excel


sum studyhours_FallSemester if in_2022followup==1 & treated==0
sum studyhours_FallSemester if reported_more==1 & treated==0
sum studyhours_FallSemester if reported_accurate==1  & treated==0




*Panel C
reg current_normal treated   if in_2022followup, r
outreg2 using Table_4c, bracket  aster(se) bdec(2) sdec(3)  keep(treated) excel replace



reg current_normal treated   if reported_more==1, r
outreg2 using Table_4c, bracket  aster(se) bdec(2) sdec(3)   keep(treated) excel


reg current_normal treated   if reported_accurate==1, r
outreg2 using Table_4c, bracket  aster(se) bdec(2) sdec(3)   keep(treated) excel



sum current_normal if in_2022followup==1 & treated==0
sum current_normal if reported_more==1 & treated==0
sum current_normal if reported_accurate==1  & treated==0


*Panel D
reg current_exam treated   if in_2022followup, r
outreg2 using Table_4d, bracket  aster(se) bdec(2) sdec(3) keep(treated) excel replace


reg current_exam treated    if reported_more==1, r
outreg2 using Table_4d, bracket  aster(se) bdec(2) sdec(3)   keep(treated) excel


reg current_exam treated    if reported_accurate==1, r
outreg2 using Table_4d, bracket  aster(se) bdec(2) sdec(3)   keep(treated) excel


sum current_exam if in_2022followup==1 & treated==0
sum current_exam if reported_more==1 & treated==0
sum current_exam if reported_accurate==1  & treated==0


*end Table 4





**************************************************************

**# Table 5: Summary Statistics for Model Parameters (2018-19 Only)

***************************************************************
sum expected_study_ability0 expected_study_ability1 expected_study_return0 expected_study_return1 pref_forA pref_forAplus procrastination


*end Table 5 




cd "${figures_path}" 

***************************
**# Figure 4 (a): Change in Economics Study Time (2018-19)

***************************

reg actual_study_diff  ability_update ,r 

local coef=string(_b[ability_update],"%9.3f")
local se=string(_se[ability_update],"%9.3f")

binscatter actual_study_diff  ability_update , ///
xline(0, lcolor(gs10)) yline(0, lcolor(gs10)) mcolor(gs0) lcolor(gs0) xtitle(Change in Beliefs about Academic Ability , size(small)) ytitle(Diff. Between Actual and Expected Econ Study Time, size(small)) ///
note("Coeff = `coef'***" "(`se')", position(2) ring(0) size(medsmall)) 
graph export "Figure_4a.pdf", as(pdf)  replace 
graph export "Figure_4a.png", as(png) name("Graph") replace


***************************
**# Figure 4 (b): Change in Economics Grade Expectations (2018-19)

***************************

reg diff_exp_grade_econ  ability_update ,r 

local coef=string(_b[ability_update],"%9.3f")
local se=string(_se[ability_update],"%9.3f")

binscatter diff_exp_grade_econ  ability_update , ///
xline(0, lcolor(gs10)) yline(0, lcolor(gs10)) mcolor(gs0) lcolor(gs0) xtitle(Change in Beliefs about Academic Ability , size(small)) ytitle(Diff. in Expected Econ Grade: Followup - Baseline, size(small)) ///
note("Coeff = `coef'***" "(`se')", position(2) ring(0) size(medsmall)) 
graph export "Figure_4b.pdf", as(pdf)  replace 
graph export "Figure_4b.png", as(png) name("Graph") replace

*end Figure 4



***************************
**# Figure B(1)(a): Change in Econ Study Time (2018-19)

***************************

reg actual_study_diff  slope_update ,r 

local coef=string(_b[slope_update],"%9.3f")
local se=string(_se[slope_update],"%9.3f")

binscatter actual_study_diff  slope_update , ///
xline(0, lcolor(gso)) yline(0, lcolor(gso))  xtitle(Change in Beliefs about Study Productivity, size(small)) ytitle(Diff. Between Actual and Expected Econ Study Time, size(small)) ///
note("Coeff = `coef'" "(`se')", position(2) ring(0) size(medsmall)) 
graph export "Figure_B1a.pdf", as(pdf)  replace 
graph export "Figure_B1a.png", as(png) name("Graph") replace 


***************************
**# Figure B(1)(b): Change in Econ Grade Expectations (2018-19)
***************************

reg diff_exp_grade_econ  slope_update ,r 

local coef=string(_b[slope_update],"%9.3f")
local se=string(_se[slope_update],"%9.3f")

binscatter diff_exp_grade_econ  slope_update , ///
xline(0, lcolor(gso)) yline(0, lcolor(gso))  xtitle(Change in Beliefs about Study Productivity , size(small)) ytitle(Diff. in Expected Econ Grade: Followup - Baseline, size(small)) ///
note("Coeff = `coef'***" "(`se')", position(3) ring(0) size(medsmall)) 
graph export "Figure_B1b.pdf", as(pdf)  replace 
graph export "Figure_B1b.png", as(png) name("Graph") replace

*end Figure B1





cd "${tables_path}" 
*********************************

**# Table B6 Columns (2) & (3)

*********************************

/*
*Panel A
reg econ_study_hours  expected_study_ability1 pref_forAplus like_to_study hsgrade 
outreg2 using Table_B6a_col2&3, bracket aster(se) bdec(3) sdec(3) replace excel
reg econ_study_hours  expected_study_return1 pref_forAplus like_to_study hsgrade 
outreg2 using Table_B6a_col2&3, bracket aster(se) bdec(3) sdec(3) append excel

sum econ_study_hours
*Panel B
reg mean_econgrade_fall expected_study_ability1  pref_forAplus procrastination like_to_study hsgrade 
outreg2 using Table_B6b_col2&3, bracket aster(se) bdec(3) sdec(3) replace excel
reg mean_econgrade_fall  expected_study_return1 pref_forAplus procrastination like_to_study hsgrade 
outreg2 using Table_B6b_col2&3, bracket aster(se) bdec(3) sdec(3) append excel

sum mean_econgrade_fall
*/
*end Table B6



***************************************************

**# Table 6: Information Updating Revisions and Changes to Study Times and Grade Expectations in 2018-19 Cohort

**************************************************
*Can only replicate columns 1, 3, 5 -- those without control variables
set more off
foreach y in actual_study_diff_econ diff_exp_grade_econ actual_minus_exp_econgrade0 {
if "`y'"=="actual_study_diff_econ"{
reg `y' ability_update , r
outreg2 using Table_6, replace  bdec(3) excel  bracket keep(ability_update) ctitle("`y', no controls") 
*reg `y' ability_update hsgrade ${controls}, r
*outreg2 using Table_6, append bdec(3) excel  bracket keep(ability_update) ctitle("`y', hs controls") 

}
else { 
reg `y' ability_update , r
outreg2 using Table_6, append  bdec(3) excel  bracket keep(ability_update) ctitle("`y', no controls") 
*reg `y' ability_update hsgrade ${controls}, r
*outreg2 using Table_6, append  bdec(3) excel  bracket keep(ability_update) ctitle("`y', hs controls") 

}
}
*
sum actual_study_diff_econ diff_exp_grade_econ actual_minus_exp_econgrade0 ability_update if ability_update<.

*end Table 6







**************************************

**# Table 8: Online Plus Two-Way Coaching Effects on Beliefs about Academic Ability, Preferences for High Grades, and Procrastination

**************************************


** The specifications in these columns in the paper include campus fixed effects
** We construct resutls withouth campus fixed effects here, which are only slighlty different.

/*
*Panel A: Beliefs about Academic Abilities
reg ability_update treated i.campus, r 
outreg2 using Table_8, bracket aster(se) bdec(3) sdec(3) keep(treated) excel replace
reg slope_update treated i.campus, r 
outreg2 using Table_8, bracket aster(se) bdec(3) sdec(3) keep(treated) excel append
*Panel B: Preferences for High Grades
reg pref_forA treated i.campus, r 
outreg2 using Table_8, bracket aster(se) bdec(3) sdec(3) keep(treated) excel append
reg pref_forAplus treated i.campus, r 
outreg2 using Table_8, bracket aster(se) bdec(3) sdec(3) keep(treated) excel append
reg grades_dont_matter_aftergrad treated i.campus, r 
outreg2 using Table_8, bracket aster(se) bdec(3) sdec(3) keep(treated) excel append
*Panel C: Procrastination
reg procrastination treated i.campus, r 
outreg2 using Table_8, bracket aster(se) bdec(3) sdec(3) keep(treated) excel append
reg sprocrast treated i.campus, r 
outreg2 using Table_8, bracket aster(se) bdec(3) sdec(3) keep(treated) excel append
*/

reg ability_update treated  , r 
outreg2 using Table_8, bracket aster(se) bdec(3) sdec(3) keep(treated) excel replace
reg slope_update treated  , r 
outreg2 using Table_8, bracket aster(se) bdec(3) sdec(3) keep(treated) excel append
*Panel B: Preferences for High Grades
reg pref_forA treated  , r 
outreg2 using Table_8, bracket aster(se) bdec(3) sdec(3) keep(treated) excel append
reg pref_forAplus treated  , r 
outreg2 using Table_8, bracket aster(se) bdec(3) sdec(3) keep(treated) excel append
reg grades_dont_matter_aftergrad treated  , r 
outreg2 using Table_8, bracket aster(se) bdec(3) sdec(3) keep(treated) excel append
*Panel C: Procrastination
reg procrastination treated  , r 
outreg2 using Table_8, bracket aster(se) bdec(3) sdec(3) keep(treated) excel append
reg sprocrast treated  , r 
outreg2 using Table_8, bracket aster(se) bdec(3) sdec(3) keep(treated) excel append
*End Table 8










cd "${figures_path}" 

****************************************
* Figures 1, 3, 6
****************************************



reshape long grade_if_xstudyhrs exp_grade_if_xstudyhrs, i(anonymized_student_id) j(hours_studying)

rename (grade_if_xstudyhrs exp_grade_if_xstudyhrs) (expected_grade_ifstdy0_hrs expected_grade_ifstdy1_hrs )

keep anonymized_student_id expected_grade_ifstdy0_hrs expected_grade_ifstdy1_hrs hours_studying procrastination  actual_study_diff_econ diff_exp_grade_econ  ability_update slope_update  econ_study_hours   econ_xstudyhrs_expected expected_econ_grade  exp_econ_grade treated  

***********************************************
**# Figure 1(a): Initial and Final Study Gradients from 2018-19 Cohort
**********************************************
keep if ability_update <.

egen tbin = tag(hours_studying)

bys hours_studying: egen mean_final_grade = mean(expected_grade_ifstdy1_hrs)
bys  hours_studying: egen mean_initial_grade = mean(expected_grade_ifstdy0_hrs)


egen tag_id = tag(anonymized_student_id)
sum econ_study_hours   if   tag_id==1
scalar final_mean_hours  = r(mean)
sum econ_xstudyhrs_expected if   tag_id==1
scalar inital_mean_hours  = r(mean)

 

sum expected_econ_grade   if   tag_id==1
scalar final_mean_grade  = r(mean)
sum exp_econ_grade if  tag_id==1
scalar inital_mean_grade  = r(mean)

 
twoway (scatter mean_final_grade hours_studying if tbin==1 , mcolor(gs10) msymbol(O)) || ///
(lfit expected_grade_ifstdy1_hrs hours_studying , lcolor(gs10) lpattern(solid)) || ///
(lfit expected_grade_ifstdy0_hrs hours_studying , lcolor(gs0) lpattern(solid)) || ///
(scatter mean_initial_grade hours_studying if tbin==1 , mcolor(gs0) msymbol(t)), scheme(sj) graphregion(icolor(white) color(white))  legend(label(1 "Final Gradient") label(4 "Initial Gradient")) legend(order(1 4)) xtitle(Study Hours) ytitle(Expected Grade)  ylabel(50(5)90) xlabel(0(2)20)
graph export "Figure_1a.pdf", as(pdf) name("Graph") replace
graph export "Figure_1a.png", as(png) name("Graph") replace


drop tbin mean_final_grade mean_initial_grade tag_id

*end of Figure 1(a)









***********************************************
**# Figure 3(a) & (b)
**********************************************

gen neg_slope = slope_update<0 if slope_update<.
gen neg_ability = ability_update<0 if ability_update<.

egen tbin = tag(hours_studying)
egen tbin_ability = tag(neg_ability hours_studying)
egen tbin_slope= tag(neg_slope hours_studying)

bys neg_ability hours_studying: egen mean_final_grade = mean(expected_grade_ifstdy1_hrs)
bys neg_ability hours_studying: egen mean_initial_grade = mean(expected_grade_ifstdy0_hrs)





egen tag_id = tag(anonymized_student_id)
sum econ_study_hours   if neg_ability==1 & tag_id==1
scalar final_mean_hours_neg = r(mean)
sum econ_xstudyhrs_expected if neg_ability==1 & tag_id==1
scalar inital_mean_hours_neg = r(mean)

sum econ_study_hours if neg_ability==0 & tag_id==1
scalar final_mean_hours_pos = r(mean)
sum econ_xstudyhrs_expected if neg_ability==0 & tag_id==1
scalar inital_mean_hours_pos = r(mean)


sum expected_econ_grade   if neg_ability==1 & tag_id==1
scalar final_mean_grade_neg = r(mean)
sum exp_econ_grade if neg_ability==1 & tag_id==1
scalar inital_mean_grade_neg = r(mean)

sum expected_econ_grade if neg_ability==0 & tag_id==1
scalar final_mean_grade_pos = r(mean)
sum exp_econ_grade if neg_ability==0 & tag_id==1
scalar inital_mean_grade_pos = r(mean)

*Fig 3(a): Study Gradients for Students with Negative Ability Update (2018-19)
twoway (scatter mean_final_grade hours_studying if tbin_ability==1 & neg_ability==1, mcolor(gs10) msymbol(O)) || ///
(lfit expected_grade_ifstdy1_hrs hours_studying if neg_ability==1, lcolor(gs10) lpattern(solid)) || ///
(lfit expected_grade_ifstdy0_hrs hours_studying if neg_ability==1, lcolor(gs0) lpattern(solid)) || ///
(scatter mean_initial_grade hours_studying if tbin_ability==1 & neg_ability==1, mcolor(gs0) msymbol(t)), scheme(sj) graphregion(icolor(white) color(white))  legend(label(1 "Final Gradient") label(4 "Initial Gradient")) legend(order(1 4)) xline(`=scalar(final_mean_hours_neg)', lcolor(gs10) lpattern(dash))  xline(`=scalar(inital_mean_hours_neg)', lcolor(gs0) lpattern(dash)) yline(`=scalar(final_mean_grade_neg)', lcolor(gs10) lpattern(dash))  yline(`=scalar(inital_mean_grade_neg)', lcolor(gs0) lpattern(dash)) xtitle(Study Hours) ytitle(Expected Grade) title(Negative Ability Update) ylabel(20(10)100) xlabel(0(2)20)
graph export "Figure_3a.pdf", as(pdf) name("Graph") replace
graph export "Figure_3a.png", as(png) name("Graph") replace


*Fig 3(b): Study Gradients for Students with Positive Ability Update (2018-19)
twoway (scatter mean_final_grade hours_studying if tbin_ability==1 & neg_ability==0, mcolor(gs10) msymbol(O)) || ///
(lfit expected_grade_ifstdy1_hrs hours_studying if neg_ability==0, lcolor(gs10) lpattern(solid)) || ///
(lfit expected_grade_ifstdy0_hrs hours_studying if neg_ability==0, lcolor(gs0) lpattern(solid)) || ///
(scatter mean_initial_grade hours_studying if tbin_ability==1 & neg_ability==0, mcolor(gs0) msymbol(t)), scheme(sj) graphregion(icolor(white) color(white))   legend(label(1 "Final Gradient") label(4 "Initial Gradient")) legend(order(1 4)) xline(`=scalar(final_mean_hours_pos)', lcolor(gs10) lpattern(dash))  xline(`=scalar(inital_mean_hours_pos)', lcolor(gs0) lpattern(dash)) yline(`=scalar(final_mean_grade_pos)', lcolor(gs10) lpattern(dash))  yline(`=scalar(inital_mean_grade_pos)', lcolor(gs0) lpattern(dash)) xtitle(Study Hours) ytitle(Expected Grade) title(Positive Ability Update) ylabel(20(10)100) xlabel(0(2)20)
graph export "Figure_3b.pdf", as(pdf) name("Graph") replace
graph export "Figure_3b.png", as(png) name("Graph") replace


*end of Figure 3







***********************************************
**# Figure 6: Final Study Gradient by Treatment Status (2018-19)
**********************************************

sum expected_econ_grade if treated==1 & tag_id ==1  
scalar econ_grade_treated = r(mean)
sum econ_study_hours if treated==1 & tag_id ==1
scalar econ_study_treated = r(mean)
sum expected_econ_grade if treated==0 & tag_id ==1 
scalar econ_grade_control = r(mean)
sum econ_study_hours if treated==0 & tag_id ==1 
scalar econ_study_control = r(mean)



binscatter expected_grade_ifstdy1_hrs hours_studying  ,   xlabel(0(1)20) ylabel(50(5)90) ///
xtitle(Study Hours Per Week in Economics) ytitle(Expected Grade in Economics) by(treated) xline(`=scalar(econ_study_control)', lcolor(gs0) lpattern(dash )) xline(`=scalar(econ_study_treated)', lcolor(gs10) lpattern(dash )) yline(`=scalar(econ_grade_control)', lcolor(gs0) lpattern(dash )) yline(`=scalar(econ_grade_treated)', lcolor(gs10) lpattern(dash )) legend(label(1 "Control") label(2 "Treated")) msymbols(t O) mcolors(gs0 gs10) lcolors(gs0 gs10)
graph export "Figure_6.pdf", as(pdf) name("Graph") replace
graph export "Figure_6.png", as(png) name("Graph") replace

**end of Figure 6




