/*
This code produces the following output:

* Table 1, Column 10
* Table 5: Columns 4 & 5
* Table 7 [Can only replicate columns 1, 3, 5, 7 -- those without control variables.]

* Table B6: Columns 4 & 5 [Not possible with data in replication packageon package]

* Figure 1: b
* Figure 3: c & d
* Figure 4: c & d 

* Figure B1: c & d

Code should be run sequentially, in order.

*/

**Set directories. Select the directory where the analysis data is located, one where temporary files will be stored as the code runs, and directories for table and figure output.
global YOUR_PATH_HERE " "

*Analysis Data File Directory:
global input_path "${YOUR_PATH_HERE}\3 replication package\data\input\"
*Temporary Folder Directory (to store output and temporary data file)
global temp_path "${YOUR_PATH_HERE}\3 replication package\data\temp"
*Folder to store tables
global tables_path "${YOUR_PATH_HERE}\3 replication package\output\tables"
*Folder to store figures
global figures_path "${YOUR_PATH_HERE}\3 replication package\output\figures"





*Bring in the analysis data
use "${input_path}year6_anlaysis_file_anonymized1.dta", clear



/*

***********************************************
*	House Keeping: Clean up Study Gradients
***********************************************
*/
sum expected_study_ability0 expected_study_ability1 expected_study_return0 expected_study_return1, detail 

replace expected_study_ability0=. if expected_study_return0<0
replace expected_study_return0=. if expected_study_return0<0
replace expected_study_ability1=. if expected_study_return1<0
replace expected_study_return1=. if expected_study_return1<0


gen ability_update = expected_study_ability1 - expected_study_ability0
gen slope_update = expected_study_return1 - expected_study_return0


sum ability_update slope_update , detail

**Cannot do this with publicly available data
/*
global controls "c.expected_avg_grade0##c.expected_avg_grade0##c.expected_avg_grade0 c.wkly_stdyhrs_nomdtrm_expctd##c.wkly_stdyhrs_nomdtrm_expctd##c.wkly_stdyhrs_nomdtrm_expctd c.wkly_stdyhrsecon_nomdtrm_expctd##c.wkly_stdyhrsecon_nomdtrm_expctd##c.wkly_stdyhrsecon_nomdtrm_expctd age first_year_student_rosi first_gen_student male canadian english hs_admissions_grade i.campus_rosi i.approach_to_college0  i.cram0 commute_time_mins wantadvanceddegree0 expected_work_hours_perweek"
*/


/*
***********************************************
* Create infor updating variables
***********************************************
*/

*Get the difference betweeen what they DID study during sem in econ relative to what they expected at baseline:
gen actual_study_diff =  wkly_stdyhrs_nomdtrm_actual - wkly_stdyhrs_nomdtrm_expctd
*Get the difference in the grade they expect to get now in econ and what they expected at followup
gen diff_exp_grade  = expected_avg_grade1 - expected_avg_grade0
*Get the diff in actual econ grade and expected at basline:
gen actual_minus_exp_grade0 = mean_grade_fall - expected_avg_grade0


*Proacrastination
gen procrastination  = wkly_stdyhrs_nomdtrm_NextSem - wkly_stdyhrs_nomdtrm_actual


*gen min acceptable grade change
gen min_acceptable_grade_change = min_acptble_avggrade1 - min_acptble_avggrade0

*Preferences for good grades
gen pref_forAplus1 = hrs_willto_study85_1- hrs_willto_study75_1
gen pref_forAplus0 = hrs_willto_study85_0- hrs_willto_study75_0
gen change_in_pref = pref_forAplus1 - pref_forAplus0




**# Appendix B: Common Costs
sum expected_work_hours_perweek, detail
gen alotofwork = expected_work > r(p75) if expected_work<.
sum commute , detail
gen longcommue = commute  > r(p75) if commute <.


reg pref_forAplus1 alotofwork
reg pref_forAplus1 longcommue 

reg pref_forAplus0 alotofwork
reg pref_forAplus0 longcommue 

reg procrastination alotofwork
reg procrastination longcommue 

reg weekly_procrastination alotofwork
reg weekly_procrastination longcommue 


/*
********************************************************************************
********************************************************************************
********************************************************************************

		Tables & Figures

********************************************************************************
********************************************************************************
********************************************************************************
*/

********************************
**# Table 1, Column (10)
*********************************
tab treated

* end Table 1


**# Appendix B: Linear Approx
sum r2_0 r2_1 r2q_0 r2q_1, detail
corr r2_0 r2q_0
corr r2_1 r2q_1

*end Correlations




**************************************************************

**# Table 5: Summary Statistics for Model Parameters (2019-20 Only)

***************************************************************
sum expected_study_ability0 expected_study_ability1 expected_study_return0 expected_study_return1 pref_forAplus0  pref_forAplus1 procrastination

*end Table 5 




cd "${figures_path}" 

***************************
**# Figure 4 (c): Change in All Course Study Time (2019-20)
***************************


reg actual_study_diff  ability_update ,r 

local coef=string(_b[ability_update],"%9.3f")
local se=string(_se[ability_update],"%9.3f")

binscatter actual_study_diff  ability_update , ///
xline(0, lcolor(gs10)) yline(0, lcolor(gs10)) mcolor(gs0) lcolor(gs0)  xtitle(Change in Beliefs about Academic Ability , size(small)) ytitle(Diff. Between Actual and Expected Study Time, size(small)) ///
note("Coeff = `coef'***" "(`se')", position(2) ring(0) size(medsmall)) xlabel(-50(10)50)
graph export "Figure_4c.pdf", as(pdf)  replace 
graph export "Figure_4c.png", as(png) name("Graph") replace



***************************
**# Figure 4 (d): Change in All Course Grade Expectations (2019-20)
***************************

reg diff_exp_grade ability_update ,r 

local coef=string(_b[ability_update],"%9.3f")
local se=string(_se[ability_update],"%9.3f")

binscatter diff_exp_grade ability_update , ///
xline(0, lcolor(gs10)) yline(0, lcolor(gs10)) mcolor(gs0) lcolor(gs0)   xtitle(Change in Beliefs about Academic Ability , size(small)) ytitle(Diff. in Expected Grade: Followup - Baseline, size(small)) ///
note("Coeff = `coef'***" "(`se')", position(3) ring(0) size(medsmall)) xlabel(-50(10)50)
graph export "Figure_4d.pdf", as(pdf)  replace 
graph export "Figure_4d.png", as(png) name("Graph") replace


*end Figure 4



***************************
**# Figure B(1)(c): Change in All Course Study Time (2019-20)
***************************


reg actual_study_diff  slope_update ,r 

local coef=string(_b[slope_update],"%9.3f")
local se=string(_se[slope_update],"%9.3f")

binscatter actual_study_diff  slope_update , ///
xline(0, lcolor(gso)) yline(0, lcolor(gso))  xtitle(Change in Beliefs about Study Productivity, size(small)) ytitle(Diff. Between Actual and Expected  Study Time, size(small)) ///
note("Coeff = `coef'***" "(`se')", position(2) ring(0) size(medsmall)) 
graph export "Figure_B1c.pdf", as(pdf)  replace 
graph export "Figure_B1c.png", as(png) name("Graph") replace


***************************
**# Figure B(1)(d): Change in All Course Grade Expectations (2019-20)
***************************

reg diff_exp_grade  slope_update ,r 

local coef=string(_b[slope_update],"%9.3f")
local se=string(_se[slope_update],"%9.3f")

binscatter diff_exp_grade  slope_update , ///
xline(0, lcolor(gso)) yline(0, lcolor(gso))  xtitle(Change in Beliefs about Study Productivity , size(small)) ytitle(Diff. in Expected  Grade: Followup - Baseline, size(small)) ///
note("Coeff = `coef'" "(`se')", position(3) ring(0) size(medsmall)) 
graph export "Figure_B1d.pdf", as(pdf)  replace 
graph export "Figure_B1d.png", as(png) name("Graph") replace

*end Figure B1






cd "${tables_path}" 
*********************************

**# Table B6 Columns (4) & (5)

*********************************
/*
*Panel A

reg  wkly_stdyhrs_nomdtrm_actual  expected_study_ability1 pref_forAplus1 like_to_study1 hs_admissions_grade 
outreg2 using Table_B6a_col4&5, bracket aster(se) bdec(3) sdec(3) replace excel
reg  wkly_stdyhrs_nomdtrm_actual  expected_study_return1 pref_forAplus1 like_to_study1 hs_admissions_grade
outreg2 using Table_B6a_col4&5, bracket aster(se) bdec(3) sdec(3) append excel

sum  wkly_stdyhrs_nomdtrm_actual

*Panel B
reg mean_grade_fall expected_study_ability1  pref_forAplus1  procrastination like_to_study1 hs_admissions_grade 
outreg2 using Table_B6b_col4&5, bracket aster(se) bdec(3) sdec(3) replace excel
reg mean_grade_fall  expected_study_return1 pref_forAplus1  procrastination like_to_study1 hs_admissions_grade  
outreg2 using Table_B6b_col4&5, bracket aster(se) bdec(3) sdec(3) append excel

sum mean_grade_fall
*/
*end Table B6






***************************************************

**# Table 7: Information Updating Revisions and Changes to Study Times and Grade Expectations in 2018-19 Cohort

**************************************************
*Can only replicate columns 1, 3, 5, 7 -- those without control variables
set more off
foreach y in actual_study_diff diff_exp_grade min_acceptable_grade_change actual_minus_exp_grade0 {
if "`y'"=="actual_study_diff"{
reg `y' ability_update   change_in_pref weekly_procrastination, r
outreg2 using Table_7, replace   bdec(3) excel  bracket keep(ability_update  change_in_pref weekly_procrastination) ctitle("`y', no controls")
*reg `y' ability_update  change_in_pref weekly_procrastination ${controls}, r
*outreg2 using Table_7, append   bdec(3) excel  bracket keep(ability_update   change_in_pref weekly_procrastination) ctitle("`y', controls hs")

}
else { 
reg `y' ability_update   change_in_pref weekly_procrastination, r
outreg2 using Table_7, append  bdec(3) excel  bracket keep(ability_update   change_in_pref weekly_procrastination) ctitle("`y', no controls")
*reg `y' ability_update  change_in_pref weekly_procrastination ${controls}, r
*outreg2 using Table_7, append   bdec(3) excel  bracket keep(ability_update   change_in_pref weekly_procrastination) ctitle("`y', controls hs")

}
}
sum actual_study_diff diff_exp_grade min_acceptable_grade_change actual_minus_exp_grade0 change_in_pref weekly_procrastination ability_update if ability_update<.

*end Table 7










cd "${figures_path}" 
****************************************
* Figures 1, 3
****************************************


rename expected_grade_ifstdy_0hrs0 expected_grade_ifstdy0_hrs0
rename expected_grade_ifstdy_5hrs0 expected_grade_ifstdy0_hrs5
rename expected_grade_ifstdy_10hrs0 expected_grade_ifstdy0_hrs10
rename expected_grade_ifstdy_15hrs0 expected_grade_ifstdy0_hrs15
rename expected_grade_ifstdy_20hrs0 expected_grade_ifstdy0_hrs20
rename expected_grade_ifstdy_25hrs0 expected_grade_ifstdy0_hrs25
rename expected_grade_ifstdy_30hrs0 expected_grade_ifstdy0_hrs30
rename expected_grade_ifstdy_35hrs0 expected_grade_ifstdy0_hrs35
rename expected_grade_ifstdy_40hrs0 expected_grade_ifstdy0_hrs40
rename expected_grade_ifstdy_45hrs0 expected_grade_ifstdy0_hrs45
rename expected_grade_ifstdy_50hrs0 expected_grade_ifstdy0_hrs50

rename expected_grade_ifstdy_0hrs1 expected_grade_ifstdy1_hrs0
rename expected_grade_ifstdy_5hrs1 expected_grade_ifstdy1_hrs5
rename expected_grade_ifstdy_10hrs1 expected_grade_ifstdy1_hrs10
rename expected_grade_ifstdy_15hrs1 expected_grade_ifstdy1_hrs15
rename expected_grade_ifstdy_20hrs1 expected_grade_ifstdy1_hrs20
rename expected_grade_ifstdy_25hrs1 expected_grade_ifstdy1_hrs25
rename expected_grade_ifstdy_30hrs1 expected_grade_ifstdy1_hrs30
rename expected_grade_ifstdy_35hrs1 expected_grade_ifstdy1_hrs35
rename expected_grade_ifstdy_40hrs1 expected_grade_ifstdy1_hrs40
rename expected_grade_ifstdy_45hrs1 expected_grade_ifstdy1_hrs45
rename expected_grade_ifstdy_50hrs1 expected_grade_ifstdy1_hrs50


reshape long expected_grade_ifstdy0_hrs expected_grade_ifstdy1_hrs, i(anonymized_student_id) j(hours_studying)

keep anonymized_student_id expected_grade_ifstdy0_hrs expected_grade_ifstdy1_hrs hours_studying procrastination min_acceptable_grade_change pref_forAplus1 pref_forAplus0 change_in_pref actual_study_diff diff_exp_grade ability_update slope_update   wkly_stdyhrs_nomdtrm_actual wkly_stdyhrs_nomdtrm_expctd expected_avg_grade1   expected_avg_grade0



gen neg_slope = slope_update<0 if slope_update<.
gen neg_ability = ability_update<0 if ability_update<.



***********************************************
**# Figure 1(b): Initial and Final Study Gradients from 2019-20 Cohort
**********************************************
egen tbin = tag(hours_studying)
bys  hours_studying: egen mean_final_grade = mean(expected_grade_ifstdy1_hrs)
bys   hours_studying: egen mean_initial_grade = mean(expected_grade_ifstdy0_hrs)

egen tag_id = tag(anonymized_student_id)
sum wkly_stdyhrs_nomdtrm_actual if tag_id==1 & ability_update<.
scalar final_mean_hours = r(mean)
sum wkly_stdyhrs_nomdtrm_expctd if  tag_id==1 & ability_update<.
scalar inital_mean_hours = r(mean)

 
sum expected_avg_grade1 if  tag_id==1 & ability_update<.
scalar final_mean_grade = r(mean)
sum expected_avg_grade0 if  tag_id==1 & ability_update<.
scalar inital_mean_grade = r(mean)

twoway (scatter mean_final_grade hours_studying if tbin==1 , mcolor(gs10) msymbol(O)) || ///
(lfit expected_grade_ifstdy1_hrs hours_studying , lcolor(gs10) lpattern(solid)) || ///
(lfit expected_grade_ifstdy0_hrs hours_studying , lcolor(gs0) lpattern(solid)) || ///
(scatter mean_initial_grade hours_studying if tbin==1 , mcolor(gs0) msymbol(t)), scheme(sj) graphregion(icolor(white) color(white))  legend(label(1 "Final Gradient") label(4 "Initial Gradient")) legend(order(1 4)) xtitle(Study Hours) ytitle(Expected Grade) ylabel(30(10)100) xlabel(0(5)50)
graph export "Figure_1b.pdf", as(pdf) name("Graph") replace
 graph export "Figure_1b.png", as(png) name("Graph") replace


drop tbin mean_final_grade mean_initial_grade tag_id


*end of Figure 1(b)



***********************************************
**# Figure 3(c) & (d)
**********************************************

egen tbin_ability = tag(neg_ability hours_studying)
egen tbin_slope= tag(neg_slope hours_studying)

bys neg_ability hours_studying: egen mean_final_grade = mean(expected_grade_ifstdy1_hrs)
bys neg_ability hours_studying: egen mean_initial_grade = mean(expected_grade_ifstdy0_hrs)





egen tag_id = tag(anonymized_student_id)
sum wkly_stdyhrs_nomdtrm_actual if neg_ability==1 & tag_id==1
scalar final_mean_hours_neg = r(mean)
sum wkly_stdyhrs_nomdtrm_expctd if neg_ability==1 & tag_id==1
scalar inital_mean_hours_neg = r(mean)

sum wkly_stdyhrs_nomdtrm_actual if neg_ability==0 & tag_id==1
scalar final_mean_hours_pos = r(mean)
sum wkly_stdyhrs_nomdtrm_expctd if neg_ability==0 & tag_id==1
scalar inital_mean_hours_pos = r(mean)


sum expected_avg_grade1 if neg_ability==1 & tag_id==1
scalar final_mean_grade_neg = r(mean)
sum expected_avg_grade0 if neg_ability==1 & tag_id==1
scalar inital_mean_grade_neg = r(mean)

sum expected_avg_grade1 if neg_ability==0 & tag_id==1
scalar final_mean_grade_pos = r(mean)
sum expected_avg_grade0 if neg_ability==0 & tag_id==1
scalar inital_mean_grade_pos = r(mean)

*Fig 3(c): Study Gradients for Students with Negative Ability Update (2019-20)
twoway (scatter mean_final_grade hours_studying if tbin_ability==1 & neg_ability==1,  mcolor(gs10) msymbol(O)) || ///
(lfit expected_grade_ifstdy1_hrs hours_studying if neg_ability==1, lcolor(gs10) lpattern(solid)) || ///
(lfit expected_grade_ifstdy0_hrs hours_studying if neg_ability==1, lcolor(gs0) lpattern(solid)) || ///
(scatter mean_initial_grade hours_studying if tbin_ability==1 & neg_ability==1,  mcolor(gs0) msymbol(t)), scheme(sj) graphregion(icolor(white) color(white))  legend(label(1 "Final Gradient") label(4 "Initial Gradient")) legend(order(1 4))  xline(`=scalar(final_mean_hours_neg)', lcolor(gs10) lpattern(dash))  xline(`=scalar(inital_mean_hours_neg)', lcolor(gs0) lpattern(dash)) yline(`=scalar(final_mean_grade_neg)', lcolor(gs10) lpattern(dash))  yline(`=scalar(inital_mean_grade_neg)', lcolor(gs0) lpattern(dash)) xtitle(Study Hours) ytitle(Expected Grade) title(Negative Ability Update) ylabel(20(10)100) xlabel(0(5)50)
graph export "Figure_3c.pdf", as(pdf) name("Graph") replace
graph export "Figure_3c.png", as(png) name("Graph") replace

*Fig 3(d): Study Gradients for Students with Positive Ability Update (2010-20)
twoway (scatter mean_final_grade hours_studying if tbin_ability==1 & neg_ability==0,  mcolor(gs10) msymbol(O)) || ///
(lfit expected_grade_ifstdy1_hrs hours_studying if neg_ability==0, lcolor(gs10) lpattern(solid)) || ///
(lfit expected_grade_ifstdy0_hrs hours_studying if neg_ability==0, lcolor(gs0) lpattern(solid)) || ///
(scatter mean_initial_grade hours_studying if tbin_ability==1 & neg_ability==0, mcolor(gs0) msymbol(t)), scheme(sj) graphregion(icolor(white) color(white))   legend(label(1 "Final Gradient") label(4 "Initial Gradient")) legend(order(1 4)) xline(`=scalar(final_mean_hours_pos)', lcolor(gs10) lpattern(dash))  xline(`=scalar(inital_mean_hours_pos)', lcolor(gs0) lpattern(dash)) yline(`=scalar(final_mean_grade_pos)', lcolor(gs10) lpattern(dash))  yline(`=scalar(inital_mean_grade_pos)', lcolor(gs0) lpattern(dash)) xtitle(Study Hours) ytitle(Expected Grade) title(Positive Ability Update) ylabel(20(10)100) xlabel(0(5)50)
graph export "Figure_3d.pdf", as(pdf) name("Graph") replace
graph export "Figure_3d.png", as(png) name("Graph") replace


*end of Figure 3


