/*
This code produces the following output:

* Table 1 (columns 1 to 9)
* Table 2
* Table 3 

* Table A1 
* Table A2

* Table B1 
* Table B2
* Table B3 
* Table B4 

* Figure A1 
* Figure A2
* Figure A9


Code should be run sequentially, in order.
*/

**Set directories. Select the directory where the analysis data is located, one where temporary files will be stored as the code runs, and directories for table and figure output.
global YOUR_PATH_HERE " "

*Analysis Data File Directory:
global input_path "${YOUR_PATH_HERE}\4 Confidential data not for publication\"
*Temporary Folder Directory (to store output and temporary data file)
global temp_path "${YOUR_PATH_HERE}\3 replication package\data\temp"
*Folder to store tables
global tables_path "${YOUR_PATH_HERE}\3 replication package\output\tables"
*Folder to store figures
global figures_path "${YOUR_PATH_HERE}\3 replication package\output\figures"



*Bring in the analysis data
use "${input_path}treatment_effects_analysis_file_anonymized1_confidential.dta", clear




*********************************************************************************************
*********************************************************************************************
**# Table 1: Random Assignment to Different Treatment and Control Groups Across Year and Campus
*			    Columns (2) to (9) -- Column (10) is constructed in other file
*********************************************************************************************
*********************************************************************************************
*Produce Table 1 without dropping goal-setting and mindset observations from the data, but don't include them in the table. 

*We'll keep them so that we get proportions of students assigned to other treatments correct. 
*The mindset and goal-setting observations are in different, standalone papers. See paper for details. 

*********************************************************************************************
*********************************************************************************************




* THIS PART PRODUCES DATA FOR TABLE 1
tab treated if balance_group == 2 //do not put mindset stats in Table 1 
tab treated if balance_group == 3
tab treated if balance_group == 4
tab treated if balance_group == 5
tab treated if balance_group == 6
tab treated if balance_group == 7 //do not put mindset stats in Table 1 
tab treated if balance_group == 8
tab treated if balance_group == 10
**End of Table 1 






**Now that Table 1 is done, set the main sample by dropping goal-setting and mindset:



****************************
* Drop goal-setting sample *
****************************
*This was only treatment this year. So cannot estimate any other effects. Drop enitre year:
drop if year==2014

****************************
* Drop mindset 2015 sample *
****************************
*Only first years could be assinged to this, but they were assigned to other treatments too.
*Drop just the mindset treated group then, as we can still estimate other treatment effects this year.
drop if group=="2 belonging mindset" 


*****************************
* Drop mindset 2017 samples *
*****************************
drop if  balance_group == 9
drop if balance_group == 7 & (group=="4 economics mindset" | group=="4 international belonging")





cd "${tables_path}" 


*********************************************************************************************
*********************************************************************************************
**# 				Table A1: Descriptive Statistics and Balance Tests
*********************************************************************************************
*********************************************************************************************

gen firstgen = (fathers_educ<6 & mothers_educ<6)
gen gradschl_parent = (fathers_educ>6 | mothers_educ>6)
gen exp_gradschl = (expected_education>=4)
gen firstyear_student = (first_year=="Yes")
gen int_student = (international=="Yes")
gen no_hsgrade = hsgrade==.



*Control Means:
sum exp_gradschl fathers mothers firstgen gradschl firstyear_student int_student tend_not_to_cram expected_fall_studyhours expected_fall_workhours if treated==0
sum expected_fall_grade days_since_sept1 grit_finish completed_warmup if treated==0
sum english male age no_hsgrade hsgrade if treated==0

*Estimated treatment differences:
xi: reg exp_gradschl i.treated i.balance_group
outreg2 using Table_A1, replace bracket aster(se) bdec(2) sdec(3) keep(_Itreated_*) excel
xi: reg fathers_educ i.treated i.balance_group
outreg2 using Table_A1, bracket   aster(se) bdec(2) sdec(3) keep(_Itreated_*) excel
xi: reg mothers_educ i.treated i.balance_group
outreg2 using Table_A1, bracket  aster(se) bdec(2) sdec(3) keep(_Itreated_*) excel
xi: reg firstgen i.treated i.balance_group
outreg2 using Table_A1, bracket  aster(se) bdec(2) sdec(3) keep(_Itreated_*) excel
xi: reg gradschl_parent i.treated i.balance_group
outreg2 using Table_A1, bracket  aster(se) bdec(2) sdec(3) keep(_Itreated_*) excel
xi: reg firstyear_student i.treated i.balance_group
outreg2 using Table_A1, bracket  aster(se) bdec(2) sdec(3) keep(_Itreated_*) excel
xi: reg int_student i.treated i.balance_group
outreg2 using Table_A1, bracket  aster(se) bdec(2) sdec(3) keep(_Itreated_*) excel
xi: reg tend_not_to_cram i.treated i.balance_group
outreg2 using Table_A1, bracket  aster(se) bdec(2) sdec(3) keep(_Itreated_*) excel
xi: reg expected_fall_studyhours i.treated i.balance_group
outreg2 using Table_A1, bracket  aster(se) bdec(2) sdec(3) keep(_Itreated_*) excel
xi: reg expected_fall_workhours i.treated i.balance_group
outreg2 using Table_A1, bracket  aster(se) bdec(2) sdec(3) keep(_Itreated_*) excel
xi: reg expected_fall_grade i.treated i.balance_group
outreg2 using Table_A1, bracket  aster(se) bdec(2) sdec(3) keep(_Itreated_*) excel
xi: reg days_since_sept1 i.treated i.balance_group
outreg2 using Table_A1, bracket  aster(se) bdec(2) sdec(3) keep(_Itreated_*) excel
xi: reg grit_finish i.treated i.balance_group
outreg2 using Table_A1, bracket  aster(se) bdec(2) sdec(3) keep(_Itreated_*) excel

xi: reg english i.treated i.balance_group
outreg2 using Table_A1, bracket   aster(se) bdec(2) sdec(3) keep(_Itreated_*) excel
xi: reg male i.treated i.balance_group
outreg2 using Table_A1, bracket   aster(se) bdec(2) sdec(3) keep(_Itreated_*) excel
xi: reg age i.treated i.balance_group
outreg2 using Table_A1, bracket   aster(se) bdec(2) sdec(3) keep(_Itreated_*) excel
xi: reg no_hsgrade i.treated i.balance_group
outreg2 using Table_A1, bracket   aster(se) bdec(2) sdec(3) keep(_Itreated_*) excel
xi: reg hsgrade i.treated i.balance_group
outreg2 using Table_A1, bracket  aster(se)  bdec(2) sdec(3) keep(_Itreated_*) excel 

**End of Table A1 


cd "${figures_path}" 
*********************************************************************************************
*********************************************************************************************
**# 		Figure A1 & A2: Fall Term Grade Distribution & Total Credits Completed by End of First Year of Experiment (Sept-Aug)
*********************************************************************************************
*********************************************************************************************

kdensity fall_meangrade_year1, bwidth(2)
graph export "Figure_A1.pdf", as(pdf)  replace 
graph export "Figure_A1.png", as(png) name("Graph") replace


histogram fullyear_credits_year1 if fullyear_credits_year1<=8, discrete width(1) start(0) fraction fcolor(gs10) lcolor(black) xtitle(Credits Completed End of First Year of Experiment) xlabel(0(1)8) title("") 
graph export "Figure_A2.pdf", as(pdf)  replace 
graph export "Figure_A2.png", as(png) name("Graph") replace

**End of Figures A1 and A2 



*Save temp data
save "${temp_path}\temp.dta", replace




cd "${tables_path}" 

*********************************************************************************************
*********************************************************************************************
**# 				Table A2: Control Group Outcome Means and Standard Deviations by Cohort and Year Since Experiment
*********************************************************************************************
*********************************************************************************************

keep if treated==0



sum fall_meangrade_year1 if year==2015
sum winter_meangrade_year1 if year==2015
sum fullyear_meangrade_year1 if year==2015
sum fullyear_meangrade_year2 if year==2015
sum fullyear_meangrade_year3 if year==2015
sum fullyear_meangrade_year4 if year==2015 


sum fall_meangrade_year1 if year==2016
sum winter_meangrade_year1 if year==2016
sum fullyear_meangrade_year1 if year==2016
sum fullyear_meangrade_year2 if year==2016
sum fullyear_meangrade_year3 if year==2016 
sum fullyear_meangrade_year4 if year==2016 


sum fall_meangrade_year1 if year==2017
sum winter_meangrade_year1 if year==2017
sum fullyear_meangrade_year1 if year==2017
sum fullyear_meangrade_year2 if year==2017 
sum fullyear_meangrade_year3 if year==2017 


sum fall_meangrade_year1 if year==2018
sum winter_meangrade_year1 if year==2018 
sum fullyear_meangrade_year1 if year==2018 
sum fullyear_meangrade_year2 if year==2018 




replace fullyear_credits_year1=0 if fullyear_credits_year1==. & year<=2018  
replace fullyear_credits_year2=0 if fullyear_credits_year2==. & year<=2017 
replace fullyear_credits_year3=0 if fullyear_credits_year3==. & year<=2016 
replace fullyear_credits_year4=0 if fullyear_credits_year4==. & year<=2015 

sum fullyear_credits_year1 if year==2015
sum fullyear_credits_year2 if year==2015
sum fullyear_credits_year3 if year==2015
sum fullyear_credits_year4 if year==2015 

sum fullyear_credits_year1 if year==2016
sum fullyear_credits_year2 if year==2016
sum fullyear_credits_year3 if year==2016 
sum fullyear_credits_year4 if year==2016

sum fullyear_credits_year1 if year==2017
sum fullyear_credits_year2 if year==2017 
sum fullyear_credits_year3 if year==2017 

sum fullyear_credits_year1 if year==2018 
sum fullyear_credits_year2 if year==2018 




sum persist_year2 if year==2015 & session1==20159
sum persist_year3 if year==2015 & session1==20159
sum persist_year4 if year==2015 & session1==20159
sum degree_in4 if year==2015 & session1==20159
sum degree_in5 if year==2015 & session1==20159

sum persist_year2 if year==2016 & session1==20169
sum persist_year3 if year==2016 & session1==20169
sum persist_year4 if year==2016 & session1==20169 
sum degree_in4 if year==2016 & session1==20169


sum persist_year2 if year==2017 & session1==20179
sum persist_year3 if year==2017 & session1==20179 


sum persist_year2 if year==2018 & session1==20189 


*End of Table A2



*********************************************************************************************
*********************************************************************************************
**#  			Table 2: Estimated Treatment Effects on Academic Performance and Persistence
*********************************************************************************************
*********************************************************************************************


use "${temp_path}\temp.dta", clear

*Control Means
sum fall_meangrade_year1 if treated==0
sum winter_meangrade_year1 if treated==0
sum fullyear_credits_year1 if treated==0
sum fullyear_meangrade_year1 if treated==0
sum persist_year2 if treated==0
sum fullyear_credits_year2 if treated==0
sum fullyear_meangrade_year2 if treated==0

sum persist_year3 if treated==0 & year<2018 
sum fullyear_credits_year3 if treated==0 & year<2018 
sum fullyear_meangrade_year3 if treated==0 & year<2018 

sum persist_year4 if treated==0 & year<2017
sum fullyear_credits_year4 if treated==0 & year<2017
sum fullyear_meangrade_year4 if treated==0 & year<2017
sum graduated if treated==0 & year<2017

*Reg results - separate treatments:
xi: reg fullyear_credits_year1 online_nocoach online_oneway online_twoway online_f2f i.balance_group 
outreg2 using Table_2a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2) excel replace
xi: reg fullyear_meangrade_year1 online_nocoach online_oneway online_twoway online_f2f i.balance_group 
outreg2 using Table_2a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2) excel
xi: reg persist_year2 online_nocoach online_oneway online_twoway online_f2f i.balance_group 
outreg2 using Table_2a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2) excel
xi: reg fullyear_credits_year2 online_nocoach online_oneway online_twoway online_f2f i.balance_group  
outreg2 using Table_2a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2) excel
xi: reg fullyear_meangrade_year2 online_nocoach online_oneway online_twoway online_f2f i.balance_group 
outreg2 using Table_2a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2) excel
xi: reg persist_year3 online_nocoach online_oneway online_twoway online_f2f i.balance_group if year<2018  
outreg2 using Table_2a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2) excel
xi: reg fullyear_credits_year3 online_nocoach online_oneway online_twoway online_f2f i.balance_group if year<2018   
outreg2 using Table_2a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2) excel
xi: reg fullyear_meangrade_year3 online_nocoach online_oneway online_twoway online_f2f i.balance_group if year<2018   
outreg2 using Table_2a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2) excel  
xi: reg persist_year4 online_nocoach online_oneway online_twoway online_f2f i.balance_group if year<2017  
outreg2 using Table_2a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2) excel
xi: reg fullyear_credits_year4 online_nocoach online_oneway online_twoway online_f2f i.balance_group if year<2017   
outreg2 using Table_2a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2) excel
xi: reg fullyear_meangrade_year4 online_nocoach online_oneway online_twoway online_f2f i.balance_group if year<2017   
outreg2 using Table_2a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2) excel  
xi: reg graduated online_nocoach online_oneway online_twoway online_f2f i.balance_group if year<2017  
outreg2 using Table_2a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2) excel  

**Add a row of all treatments pooled effect:
gen treated2 = treated!=0 if treated<.


xi: reg fullyear_credits_year1 treated2 i.balance_group 
outreg2 using Table_2b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel replace
xi: reg fullyear_meangrade_year1 treated2 i.balance_group 
outreg2 using Table_2b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel
xi: reg persist_year2 treated2 i.balance_group 
outreg2 using Table_2b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel
xi: reg fullyear_credits_year2 treated2 i.balance_group  
outreg2 using Table_2b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel
xi: reg fullyear_meangrade_year2 treated2 i.balance_group 
outreg2 using Table_2b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel
xi: reg persist_year3 treated2 i.balance_group if year<2018 
outreg2 using Table_2b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel
xi: reg fullyear_credits_year3 treated2 i.balance_group if year<2018  
outreg2 using Table_2b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel
xi: reg fullyear_meangrade_year3 treated2 i.balance_group if year<2018   
outreg2 using Table_2b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel  
xi: reg persist_year4 treated2 i.balance_group if year<2017 
outreg2 using Table_2b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel
xi: reg fullyear_credits_year4 treated2 i.balance_group if year<2017   
outreg2 using Table_2b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel
xi: reg fullyear_meangrade_year4 treated2 i.balance_group if year<2017  
outreg2 using Table_2b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel  
xi: reg graduated treated2 i.balance_group if year<2017  
outreg2 using Table_2b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel  


*End of Table 2



*********************************************************************************************
*********************************************************************************************
**#  Table B1: Estimated Treatment Effects on Academic Performance and Persistence with Additional Control Variables
*********************************************************************************************
*********************************************************************************************


use "${temp_path}\temp.dta", clear

*Control Means
sum fall_meangrade_year1 if treated==0
sum winter_meangrade_year1 if treated==0
sum fullyear_credits_year1 if treated==0
sum fullyear_meangrade_year1 if treated==0
sum persist_year2 if treated==0
sum fullyear_credits_year2 if treated==0
sum fullyear_meangrade_year2 if treated==0

sum persist_year3 if treated==0 & year<2018 
sum fullyear_credits_year3 if treated==0 & year<2018 
sum fullyear_meangrade_year3 if treated==0 & year<2018 

sum persist_year4 if treated==0 & year<2017
sum fullyear_credits_year4 if treated==0 & year<2017
sum fullyear_meangrade_year4 if treated==0 & year<2017
sum graduated if treated==0 & year<2017

*Generate controls
tab tend_not_to_cram, gen(tend_not_to_cram_dummy)
gen expected_fall_studyhours2 = expected_fall_studyhours^2
gen expected_fall_studyhours3 = expected_fall_studyhours^3
gen days_since2 = days_since_s^2
gen days_since3 = days_since_s^3
tab fathers_education, gen(fathers_education_dummy)
tab mothers_education, gen(mothers_education_dummy) 
gen age2 = age^2
gen age3 = age^3

gen missing_hsgrade = hsgrade==.
gen interact = hsgrade
replace interact = 0 if hsgrade==.

global controls "tend_not_to_cram_dummy* expected_fall_studyhours* days_since_sept1 days_since2 days_since3 fathers_education_dummy* mothers_education_dummy* age age2 age3 missing_hsgrade interact  english"

*Reg results - separate treatments:
xi: reg fullyear_credits_year1 online_nocoach online_oneway online_twoway online_f2f i.balance_group ${controls}
outreg2 using Table_B1a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel replace
xi: reg fullyear_meangrade_year1 online_nocoach online_oneway online_twoway online_f2f i.balance_group  ${controls}
outreg2 using Table_B1a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel
xi: reg persist_year2 online_nocoach online_oneway online_twoway online_f2f i.balance_group ${controls}
outreg2 using Table_B1a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel
xi: reg fullyear_credits_year2 online_nocoach online_oneway online_twoway online_f2f i.balance_group ${controls} 
outreg2 using Table_B1a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel
xi: reg fullyear_meangrade_year2 online_nocoach online_oneway online_twoway online_f2f i.balance_group ${controls} 
outreg2 using Table_B1a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel
xi: reg persist_year3 online_nocoach online_oneway online_twoway online_f2f i.balance_group ${controls} if year<2018  
outreg2 using Table_B1a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel
xi: reg fullyear_credits_year3 online_nocoach online_oneway online_twoway online_f2f i.balance_group ${controls} if year<2018   
outreg2 using Table_B1a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel
xi: reg fullyear_meangrade_year3 online_nocoach online_oneway online_twoway online_f2f i.balance_group ${controls} if year<2018  
outreg2 using Table_B1a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel  
xi: reg persist_year4 online_nocoach online_oneway online_twoway online_f2f i.balance_group ${controls} if year<2017 
outreg2 using Table_B1a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel
xi: reg fullyear_credits_year4 online_nocoach online_oneway online_twoway online_f2f i.balance_group ${controls} if year<2017   
outreg2 using Table_B1a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel
xi: reg fullyear_meangrade_year4 online_nocoach online_oneway online_twoway online_f2f i.balance_group ${controls} if year<2017 
outreg2 using Table_B1a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel  
xi: reg graduated online_nocoach online_oneway online_twoway online_f2f i.balance_group ${controls} if year<2017 
outreg2 using Table_B1a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel  



**Add a row of all treatments pooled effect:
gen treated2 = treated!=0 if treated<.

xi: reg fullyear_credits_year1 treated2 i.balance_group ${controls}
outreg2 using Table_B1b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel replace
xi: reg fullyear_meangrade_year1 treated2 i.balance_group ${controls}
outreg2 using Table_B1b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel
xi: reg persist_year2 treated2 i.balance_group ${controls}
outreg2 using Table_B1b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel
xi: reg fullyear_credits_year2 treated2 i.balance_group ${controls} 
outreg2 using Table_B1b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel
xi: reg fullyear_meangrade_year2 treated2 i.balance_group ${controls} 
outreg2 using Table_B1b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel
xi: reg persist_year3 treated2 i.balance_group ${controls} if year<2018 
outreg2 using Table_B1b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel
xi: reg fullyear_credits_year3 treated2 i.balance_group ${controls} if year<2018  
outreg2 using Table_B1b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel
xi: reg fullyear_meangrade_year3 treated2 i.balance_group ${controls} if year<2018   
outreg2 using Table_B1b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel  
xi: reg persist_year4 treated2 i.balance_group ${controls} if year<2017 
outreg2 using Table_B1b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel
xi: reg fullyear_credits_year4 treated2 i.balance_group ${controls} if year<2017    
outreg2 using Table_B1b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel
xi: reg fullyear_meangrade_year4 treated2 i.balance_group ${controls} if year<2017    
outreg2 using Table_B1b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel  
xi: reg graduated treated2 i.balance_group ${controls} if year<2017   
outreg2 using Table_B1b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel 



*end of Table B1





*********************************************************************************************
*********************************************************************************************
**#  Table B2: Treatment Effects on Academic Performance and Persistence Estimated Separately for All SAL Experiments
*********************************************************************************************
*********************************************************************************************

use "${temp_path}\temp.dta", clear

*generate individual treatment indicators
gen treated1 = 1 if group=="2 online advice no text followup"
replace treated1 = 2 if group=="2 online advice with text followup"
replace treated1 = 3 if group=="2 online advice with face-to-face followup"
replace treated1 = 4 if group=="3 choose your own challenge online only"
replace treated1 = 5 if group=="3 choose your own challenge with text personal coaching"
replace treated1 = 6 if group=="3 online advice with face-to-face followup"
replace treated1 = 7 if group=="3 online advice plus persistence plus"
replace treated1 = 8 if group=="4 study time management" | group=="5 study time management"
replace treated1 = 0 if treated==0


/*
drop balance_group

gen balance_group = 1 if year==2015 & first_year=="Yes"
replace balance_group = 2 if year==2015 & first_year=="No"
replace balance_group = 3 if year==2016 & campus=="UofT"
replace balance_group = 4 if year==2016 & campus=="UTM"
replace balance_group = 5 if year==2016 & campus=="UTSC"
replace balance_group = 6 if year==2017 & campus=="UofT"
replace balance_group = 7 if year==2017 & campus=="UTM"
replace balance_group = 8 if year==2018
*/

xi: reg fall_meangrade_year1 i.treated1 i.balance_group
outreg2 using Table_B2, replace bracket aster(se) bdec(3) sdec(3) keep(_Itreated1_*) excel
xi: reg winter_meangrade_year1 i.treated1 i.balance_group
outreg2 using Table_B2,   bracket aster(se) bdec(3) sdec(3) keep(_Itreated1_*) excel
xi: reg fullyear_meangrade_year1 i.treated1 i.balance_group
outreg2 using Table_B2,   bracket aster(se) bdec(3) sdec(3) keep(_Itreated1_*) excel
xi: reg fullyear_credits_year1 i.treated1 i.balance_group
outreg2 using Table_B2,   bracket aster(se) bdec(3) sdec(3) keep(_Itreated1_*) excel
xi: reg persist_year2 i.treated1 i.balance_group
outreg2 using Table_B2,   bracket aster(se) bdec(3) sdec(3) keep(_Itreated1_*) excel
xi: reg fullyear_meangrade_year2 i.treated1 i.balance_group
outreg2 using Table_B2,   bracket aster(se) bdec(3) sdec(3) keep(_Itreated1_*) excel
xi: reg fullyear_credits_year2 i.treated1 i.balance_group
outreg2 using Table_B2,   bracket aster(se) bdec(3) sdec(3) keep(_Itreated1_*) excel  


*end of Table B2


*********************************************************************************************
*********************************************************************************************
**#  Table B3: Estimated Treatment Effect on Fall Term Grade by Propensity Score Groups for Low Fall Grade
*********************************************************************************************
*********************************************************************************************

use "${temp_path}\temp.dta", clear


gen lowgrade = fall_meangrade_year1<60 if fall_meangrade_year1<.
xtile hs_decile = hsgrade, nq(10)
replace hs_decile = 1000 if hs_decile ==. // dummy for omitted group
tab hs_decile, gen(hs_decile_dummy)
tab tend_not_to_cram, gen(tend_not_to_cram_dummy)
gen expected_fall_studyhours2 = expected_fall_studyhours^2
gen expected_fall_studyhours3 = expected_fall_studyhours^3
gen days_since2 = days_since_s^2
gen days_since3 = days_since_s^3
tab fathers_education, gen(fathers_education_dummy)
tab mothers_education, gen(mothers_education_dummy) 
gen age2 = age^2
gen age3 = age^3

*Get Predicted Grades Based on Leave-One-Out Estimates
regress lowgrade hs_decile_dummy* tend_not_to_cram_dummy* fathers_education_dummy* mothers_education_dummy* i.balance_group days_since* english male age* expected_fall_studyhours* if treated==0
*Get leverage statistic for each observations (NOTE: install cv_regress package if you do not have it)
cv_regress, genlev(h_i)

**Predictions while dropping balance group indicators 

*prediction for treated group
gen pscore = _b[_cons] + _b[hs_decile_dummy1]*hs_decile_dummy1 +  _b[tend_not_to_cram_dummy1]*tend_not_to_cram_dummy1 + _b[fathers_education_dummy1]*fathers_education_dummy1 + _b[mothers_education_dummy1]*mothers_education_dummy1 ///
+ _b[days_since_sept1]*days_since_sept1 + _b[days_since2]*days_since2 + _b[days_since3]*days_since3 + _b[male]*male + _b[english]*english + _b[age]*age + _b[age2]*age2 + _b[age3]*age3 ///
+ _b[expected_fall_studyhours]*expected_fall_studyhours + _b[expected_fall_studyhours2]*expected_fall_studyhours2 + _b[expected_fall_studyhours3]*expected_fall_studyhours3

forvalues i = 2/10 {
	replace pscore = pscore + _b[hs_decile_dummy`i']*hs_decile_dummy`i'
}
forvalues i = 2/6{
	replace pscore = pscore + _b[tend_not_to_cram_dummy`i']*tend_not_to_cram_dummy`i'
}
forvalues i = 2/8{
	replace pscore = pscore + _b[fathers_education_dummy`i']*fathers_education_dummy`i' +  _b[mothers_education_dummy`i']*mothers_education_dummy`i'
}

*prediction for control requires the leverage stat, the predicted value, and the residual:
gen e = lowgrade - (pscore)
gen leverage_multiplier = h_i/(1-h_i)
replace pscore = pscore - leverage_multiplier*e if treated==0

egen p95 = pctile(pscore),p(95)
egen p90 = pctile(pscore),p(90)
egen p85 = pctile(pscore),p(85)
egen p80 = pctile(pscore),p(80)
egen p75 = pctile(pscore),p(75)
egen p70 = pctile(pscore),p(70)
egen p60 = pctile(pscore),p(60)
egen p50 = pctile(pscore),p(50)

*Reg results:
xi: reg fall_meangrade_year1 online_nocoach online_oneway online_twoway online_f2f i.balance_group if pscore~=.
outreg2 using Table_B3, replace bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel
xi: reg fall_meangrade_year1 online_nocoach online_oneway online_twoway online_f2f i.balance_group if pscore>p90 & pscore~=.
outreg2 using Table_B3, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel
xi: reg fall_meangrade_year1 online_nocoach online_oneway online_twoway online_f2f i.balance_group if pscore>p80 & pscore~=.
outreg2 using Table_B3, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel
xi: reg fall_meangrade_year1 online_nocoach online_oneway online_twoway online_f2f i.balance_group if pscore>p70 & pscore~=.
outreg2 using Table_B3, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel
xi: reg fall_meangrade_year1 online_nocoach online_oneway online_twoway online_f2f i.balance_group if pscore>p60 & pscore~=.
outreg2 using Table_B3, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel
xi: reg fall_meangrade_year1 online_nocoach online_oneway online_twoway online_f2f i.balance_group if pscore>p50 & pscore~=.
outreg2 using Table_B3, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel
xi: reg fall_meangrade_year1 online_nocoach online_oneway online_twoway online_f2f i.balance_group if pscore<=p50 & pscore~=.
outreg2 using Table_B3, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel 

*Control Means:
sum fall_meangrade_year1 if   pscore~=. & treated==0
sum fall_meangrade_year1 if pscore>p90 & pscore~=. & treated==0
sum fall_meangrade_year1 if pscore>p80 & pscore~=. & treated==0
sum fall_meangrade_year1 if pscore>p70 & pscore~=. & treated==0
sum fall_meangrade_year1 if pscore>p60 & pscore~=. & treated==0
sum fall_meangrade_year1 if pscore>p50 & pscore~=. & treated==0
sum fall_meangrade_year1 if pscore<=p50 & pscore~=. & treated==0



*end of Table B3




*********************************************************************************************
*********************************************************************************************
**#  Table B4: Estimated Treatment Effects on Initial Fall Term Grades [0-100] by Campus
*********************************************************************************************
*********************************************************************************************

use "${temp_path}\temp.dta", clear

gen missing_fallgrade = fall_meangrade_year1==.

*Control Means:
sum fall_meangrade_year1 if treated==0  & campus=="UofT"
sum fall_meangrade_year1 if treated==0  & campus=="UTM"
sum fall_meangrade_year1 if treated==0  & campus=="UTSC"

*Regression Results:
xi: reg fall_meangrade_year1 online_nocoach online_oneway online_twoway online_f2f i.balance_group
outreg2 using Table_B4, replace bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel
xi: reg fall_meangrade_year1 online_nocoach online_oneway online_twoway online_f2f i.balance_group if campus=="UofT"
outreg2 using Table_B4, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel
xi: reg fall_meangrade_year1 online_nocoach online_oneway online_twoway online_f2f i.balance_group if campus=="UTM"
outreg2 using Table_B4, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel
xi: reg fall_meangrade_year1 online_nocoach online_oneway online_twoway online_f2f i.balance_group if campus=="UTSC"
outreg2 using Table_B4, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel 

*end of Table B4




*********************************************************************************************
*********************************************************************************************
**#  Table 3: Estimated Treatment Effect Outcomes on Reported Study Behavior
*********************************************************************************************
*********************************************************************************************

use "${temp_path}\temp.dta", clear


**Panel A
preserve 

gen treated1 = treated!=0 & treated!=6 if treated<.

egen fallstudyhours = std(followup_fallstudyhours)
egen dontcram = std(tend_not_to_cram)
egen missedclass = std(missed_econ_class_freq)
egen learnfrommistakes = std(followup_learnfrommistakes)
egen studywithpen = std(followup_studywithpen)
egen getwritinghelp = std(followup_getwritinghelp)
egen thinkofgoals = std(followup_thinkofgoals)
egen metwithtutor = std(followup_metwithfreetutor) 
egen metwithinstructor = std(followup_metwithinstructor)
egen managemytime = std(followup_imanagemytime)
egen temp = rowmean(fallstudyhours learnfrommistakes studywithpen getwritinghelp metwithtutor metwithinstructor managemytime)
egen studyhabits = std(temp)
drop temp

gen notmissing3 = studyhabits~=.

xi: reg notmissing3 online_nocoach online_oneway online_twoway online_f2f i.balance_group if year>=2015
outreg2 using Table_3a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel replace
xi: reg fallstudyhours online_nocoach online_oneway online_twoway online_f2f i.balance_group if year>=2015
outreg2 using Table_3a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel
xi: reg dontcram online_nocoach online_oneway online_twoway online_f2f i.balance_group if year>=2015
outreg2 using Table_3a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel
xi: reg missedclass online_nocoach online_oneway online_twoway online_f2f i.balance_group if year>=2015
outreg2 using Table_3a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel
xi: reg learnfrommistakes online_nocoach online_oneway online_twoway online_f2f i.balance_group if year>=2015
outreg2 using Table_3a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel
xi: reg studywithpen online_nocoach online_oneway online_twoway online_f2f i.balance_group if year>=2015
outreg2 using Table_3a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel
xi: reg getwritinghelp online_nocoach online_oneway online_twoway online_f2f i.balance_group if year>=2015
outreg2 using Table_3a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel
xi: reg metwithtutor online_nocoach online_oneway online_twoway online_f2f i.balance_group if year>=2015
outreg2 using Table_3a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel
xi: reg managemytime online_nocoach online_oneway online_twoway online_f2f i.balance_group if year>=2015
outreg2 using Table_3a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel
xi: reg studyhabits online_nocoach online_oneway online_twoway online_f2f i.balance_group if year>=2015
outreg2 using Table_3a, bracket aster(se) bdec(3) sdec(3) keep(online_nocoach online_oneway online_twoway online_f2f) excel
xi: reg studyhabits treated1 online_f2f i.balance_group if year>=2015
outreg2 using Table_3a, bracket aster(se) bdec(3) sdec(3) keep(treated1) excel  

restore



**Panel B
preserve 

keep if year==2018

gen treated2 = treated!=0 if treated<.

gen timeuse_studytotal = timeuse_studyingalone +  timeuse_studyingwothers 


xi: reg followup_fallstudyhours  treated2  i.campus
outreg2 using Table_3b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel replace
xi: reg econ_study_hours  treated2   i.campus
outreg2 using Table_3b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel
xi: reg timeuse_studyingalone  treated2   i.campus
outreg2 using Table_3b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel
xi: reg timeuse_studyingwothers  treated2   i.campus 
outreg2 using Table_3b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel
xi: reg timeuse_studytotal  treated2  i.campus
outreg2 using Table_3b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel
xi: reg studyhours_NextSemester treated2   i.campus
outreg2 using Table_3b, bracket aster(se) bdec(3) sdec(3) keep(treated2) excel 


sum followup_fallstudyhours econ_study_hours timeuse_studyingalone timeuse_studyingwothers timeuse_studytotal studyhours_NextSemester if treated==0

restore

*end Table 3


******************************************************
**#  Figure A9: Student Feelings About the 2-Way Text-Message Coaching Program
******************************************************


cd "${figures_path}" 

rename followup_coach_support  my_coach_supports
rename followup_like_coach_msgs appreciates_receiving_messages_c
rename followup_coach_helping doing_better_uoft_because_of_coa

* agree or disagree: my coach supports me
graph bar , over(my_coach_supports, label(labsize(small) angle(45)) ) blabel(total, format(%9.2f)) ///
scheme(sj) graphregion(icolor(white) color(white)) bar(1, color(navy)) ylabel(0(10)40) ///
ytitle(Percentage of Respondents) title(I Feel my Coach Supports Me) 
graph export "Figure_A9a.pdf", as(pdf)  replace 
graph export "Figure_A9a.png", as(png) name("Graph") replace


* Agree appreciate receiving messages from coach
graph bar , over(appreciates_receiving_messages_c, label(labsize(small) angle(45)) ) blabel(total, format(%9.2f)) ///
scheme(sj) graphregion(icolor(white) color(white)) bar(1, color(navy)) ylabel(0(10)40) ///
ytitle(Percentage of Respondents) title(I Appreciate Receiving Messages from My Coach)
graph export "Figure_A9b.pdf", as(pdf)  replace 
graph export "Figure_A9b.png", as(png) name("Graph") replace


* Doing better becuase of coach
graph bar , over(doing_better_uoft_because_of_coa, label(labsize(small) angle(45)) ) blabel(total, format(%9.2f)) ///
scheme(sj) graphregion(icolor(white) color(white)) bar(1, color(navy)) ylabel(0(10)40) ///
ytitle(Percentage of Respondents) title(I'm Doing Better at Univ. In Part Because of My Coach)
graph export "Figure_A9c.pdf", as(pdf)  replace 
graph export "Figure_A9c.png", as(png) name("Graph") replace


* Program helpful 
graph bar , over(program_help, label(labsize(small) angle(45)) ) blabel(total, format(%9.2f)) ///
scheme(sj) graphregion(icolor(white) color(white)) bar(1, color(navy)) ylabel(0(10)40) ///
ytitle(Percentage of Respondents) title(Program Has Been Helpful) 
graph export "Figure_A9d.pdf", as(pdf)  replace 
graph export "Figure_A9d.png", as(png) name("Graph") replace


*woudl you like coaching next year
label define yesno 0 "No" 1 "Yes"
label values offer_program yesno
graph bar , over(should_program_continue, label(labsize(small) angle(45)) ) blabel(total, format(%9.2f)) ///
scheme(sj) graphregion(icolor(white) color(white)) bar(1, color(navy)) ylabel(0(10)90) ///
ytitle(Percentage of Respondents) title(Would You Like Coaching to Continue Next Term?)
graph export "Figure_A9e.pdf", as(pdf)  replace 
graph export "Figure_A9e.png", as(png) name("Graph") replace


*should we offer program next year
graph bar , over(offer_program_nextyear, label(labsize(small) angle(45)) ) blabel(total, format(%9.2f)) ///
scheme(sj) graphregion(icolor(white) color(white)) bar(1, color(navy)) ylabel(0(10)90) ///
ytitle(Percentage of Respondents) title(Should Program be Offered Next Year?)
graph export "Figure_A9f.pdf", as(pdf)  replace 
graph export "Figure_A9f.png", as(png) name("Graph") replace

*end Figure A9










